@@ -629,7 +629,7 @@ typedef TDSRET  tds_func_get_info(TDSSOCKET *tds, TDSCOLUMN *col);
 typedef TDSRET  tds_func_get_data(TDSSOCKET *tds, TDSCOLUMN *col);
 typedef TDS_INT tds_func_row_len(TDSCOLUMN *col);
 typedef TDSRET  tds_func_put_info(TDSSOCKET *tds, TDSCOLUMN *col);
-typedef TDSRET  tds_func_put_data(TDSSOCKET *tds, TDSCOLUMN *col, int bcp7);
+typedef TDSRET  tds_func_put_data(TDSSOCKET *tds, TDSCOLUMN *col, bool bcp7);
 typedef int     tds_func_check(const TDSCOLUMN *col);
 
 typedef struct tds_column_funcs
@@ -1548,8 +1548,18 @@ void tdsdump_log_impl(const char* file, unsigned int level_line, const char *fmt
 #endif
 #endif
 ;
-#define tdsdump_log if (TDS_UNLIKELY(tds_write_dump)) tdsdump_log_impl
-#define tdsdump_dump_buf if (TDS_UNLIKELY(tds_write_dump)) tdsdump_dump_buf_impl
+#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
+/* If available use C99 and __VA_ARGS__ */
+#define tdsdump_log(...) do { \
+	if (TDS_UNLIKELY(tds_write_dump)) tdsdump_log_impl(__VA_ARGS__); \
+} while(0)
+#define tdsdump_dump_buf(...) do { \
+	if (TDS_UNLIKELY(tds_write_dump)) tdsdump_dump_buf_impl(__VA_ARGS__); \
+} while(0)
+#else
+#define tdsdump_log if (!TDS_UNLIKELY(tds_write_dump)) {} else tdsdump_log_impl
+#define tdsdump_dump_buf if (!TDS_UNLIKELY(tds_write_dump)) {} else tdsdump_dump_buf_impl
+#endif
 
 extern bool tds_write_dump;
 extern int tds_debug_flags;
